"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClientCookieManager = void 0;
const cookieFormatter_1 = require("../utils/cookieFormatter");
const import_1 = require("../utils/import");
class ClientCookieManager {
    constructor() {
        Object.defineProperty(this, "cookie", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.cookie = [];
    }
    /**
     * @returns {number} - The amount of cookies.
     */
    get size() {
        return this.cookie.length;
    }
    setCookie(ltuid, ltoken) {
        this.cookie.push({ ltoken: ltoken, ltuid: ltuid });
    }
    /**
     * @description Get the ltoken and ltuid for request.
     * @returns {cookie} - The ltoken and ltuid.
     */
    get() {
        if (this.size === 0) {
            throw new Error("Please login first.");
        }
        const ltoken = this.cookie[0]?.ltoken;
        const ltuid = this.cookie[0]?.ltuid;
        if (!ltoken || !ltuid) {
            throw new Error("Invalid cookie");
        }
        this.cookie.splice(0, 1);
        this.cookie.push({ ltoken: ltoken, ltuid: ltuid });
        return {
            ltoken: ltoken,
            ltuid: ltuid,
            key: this.size - 1,
            cookie: (0, cookieFormatter_1.CookieFormatter)(ltoken, ltuid),
        };
    }
    /**
     * @param key - The key to remove.
     */
    delete(key) {
        this.cookie.splice(key - 1, 1);
    }
    clear() {
        this.cookie = [];
    }
    getAll() {
        const cookie = [];
        for (let i = 0; i < this.size; i++) {
            cookie[i] = {
                ltoken: this.cookie[i]?.ltoken || "",
                ltuid: this.cookie[i]?.ltuid || "",
                key: i,
                cookie: (0, cookieFormatter_1.CookieFormatter)(this.cookie[i]?.ltoken || "", this.cookie[i]?.ltuid || ""),
            };
        }
        return cookie;
    }
    async getBrowserCookie(customProfile) {
        try {
            await (0, import_1.dynamic)("chrome-cookies-secure");
        }
        catch (e) {
            throw new Error("Please install chrome-cookies-secure");
        }
        const chrome = await (0, import_1.dynamic)("chrome-cookies-secure");
        const cookie = await chrome.getCookiesPromised("https://www.hoyolab.com/", "chrome", `${customProfile}`);
        let ltoken, ltuid, cookie_token;
        for (const key in cookie) {
            if (key === "ltoken") {
                ltoken = cookie[key];
            }
            if (key === "ltuid") {
                ltuid = cookie[key];
            }
            if (key === "cookie_token") {
                cookie_token = cookie[key];
            }
        }
        if (!ltoken || !ltuid || !cookie_token) {
            throw new Error("Invalid cookie");
        }
        this.setCookie(ltuid, ltoken);
        return {
            ltoken,
            ltuid,
            cookie_token,
        };
    }
}
exports.ClientCookieManager = ClientCookieManager;
